==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/UserCreatedAcrAccountArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.UserCreatedAcrAccountArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property armResourceId ARM ResourceId of a resource
 */
public data class UserCreatedAcrAccountArgs(
    public val armResourceId: Output<ArmResourceIdArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.UserCreatedAcrAccountArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.UserCreatedAcrAccountArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.UserCreatedAcrAccountArgs.builder()
            .armResourceId(armResourceId?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [UserCreatedAcrAccountArgs].
 */
@PulumiTagMarker
public class UserCreatedAcrAccountArgsBuilder internal constructor() {
    private var armResourceId: Output<ArmResourceIdArgs>? = null

    /**
     * @param value ARM ResourceId of a resource
     */
    @JvmName("bleescbiihirfeya")
    public suspend fun armResourceId(`value`: Output<ArmResourceIdArgs>) {
        this.armResourceId = value
    }

    /**
     * @param value ARM ResourceId of a resource
     */
    @JvmName("tciniphyaafcpcvb")
    public suspend fun armResourceId(`value`: ArmResourceIdArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.armResourceId = mapped
    }

    /**
     * @param argument ARM ResourceId of a resource
     */
    @JvmName("lkiwfcxnvqxjcrsf")
    public suspend fun armResourceId(argument: suspend ArmResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = ArmResourceIdArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.armResourceId = mapped
    }

    internal fun build(): UserCreatedAcrAccountArgs = UserCreatedAcrAccountArgs(
        armResourceId = armResourceId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/UserCreatedAcrAccountArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.UserCreatedAcrAccountArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property armResourceId ARM ResourceId of a resource
 */
public data class UserCreatedAcrAccountArgs(
    public val armResourceId: Output<ArmResourceIdArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.UserCreatedAcrAccountArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.UserCreatedAcrAccountArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.UserCreatedAcrAccountArgs.builder()
            .armResourceId(armResourceId?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [UserCreatedAcrAccountArgs].
 */
@PulumiTagMarker
public class UserCreatedAcrAccountArgsBuilder internal constructor() {
    private var armResourceId: Output<ArmResourceIdArgs>? = null

    /**
     * @param value ARM ResourceId of a resource
     */
    @JvmName("qrxgdtllkxxrvcwo")
    public suspend fun armResourceId(`value`: Output<ArmResourceIdArgs>) {
        this.armResourceId = value
    }

    /**
     * @param value ARM ResourceId of a resource
     */
    @JvmName("sgtrbxnsfljuakxl")
    public suspend fun armResourceId(`value`: ArmResourceIdArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.armResourceId = mapped
    }

    /**
     * @param argument ARM ResourceId of a resource
     */
    @JvmName("rflkhjgtyqcbrssx")
    public suspend fun armResourceId(argument: suspend ArmResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = ArmResourceIdArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.armResourceId = mapped
    }

    internal fun build(): UserCreatedAcrAccountArgs = UserCreatedAcrAccountArgs(
        armResourceId = armResourceId,
    )
}
